# django-sphinx-view

Serve your Sphinx docs with Django.

Please see [the project homepage for docs][homepage].

[homepage]: https://noumenal.es/django-sphinx-view/


## Contributing

All input welcome! ⛵️

* Check out [the issues](https://github.com/carltongibson/django-sphinx-view/issues)
* Start a [Discussion with your idea](https://github.com/carltongibson/django-sphinx-view/discussions).

